summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorAnton Kindestam <antonki@kth.se>2018-04-21 15:16:30 +0200
committerJan Ekström <jeebjp@gmail.com>2018-05-01 20:48:02 +0300
commit4c6f36611d6a177e01891286a2da69aad7c4842f (patch)
tree649a342a0f615121c4398be36cff1c4943a9d219
parente60728a622a89bb792de41106ec969aad7d3dd28 (diff)
downloadmpv-4c6f36611d6a177e01891286a2da69aad7c4842f.tar.bz2
mpv-4c6f36611d6a177e01891286a2da69aad7c4842f.tar.xz
context_drm_egl: fix some comments and log messages that had not been updated since the plane rename commit
-rw-r--r--video/out/opengl/context_drm_egl.c11
1 files changed, 5 insertions, 6 deletions
diff --git a/video/out/opengl/context_drm_egl.c b/video/out/opengl/context_drm_egl.c
index 6368107327..1ba7f5dd05 100644
--- a/video/out/opengl/context_drm_egl.c
+++ b/video/out/opengl/context_drm_egl.c
@@ -526,18 +526,18 @@ static void drm_egl_uninit(struct ra_ctx *ctx)
}
}
// If primary plane supports ARGB we want to use that, but if it doesn't we fall
// back on XRGB. If the driver does not support atomic there is no particular
// reason to be using ARGB (drmprime hwdec will not work without atomic,
// anyway), so we fall back to XRGB (another reason is that we do not have the
-// convenient atomic_ctx and its convenient primary_plane field).
+// convenient atomic_ctx and its convenient plane fields).
static bool probe_gbm_format(struct ra_ctx *ctx, uint32_t argb_format, uint32_t xrgb_format)
{
struct priv *p = ctx->priv;
if (!p->kms->atomic_context) {
p->gbm_format = xrgb_format;
- MP_VERBOSE(ctx->vo, "Not using DRM Atomic: Use %s for primary plane.\n",
+ MP_VERBOSE(ctx->vo, "Not using DRM Atomic: Use %s for OSD plane.\n",
gbm_format_to_string(xrgb_format));
return true;
}
@@ -557,11 +557,11 @@ static bool probe_gbm_format(struct ra_ctx *ctx, uint32_t argb_format, uint32_t
if (have_argb) {
p->gbm_format = argb_format;
- MP_VERBOSE(ctx->vo, "%s supported by primary plane.\n", gbm_format_to_string(argb_format));
+ MP_VERBOSE(ctx->vo, "%s supported by OSD plane.\n", gbm_format_to_string(argb_format));
result = true;
} else if (have_xrgb) {
p->gbm_format = xrgb_format;
- MP_VERBOSE(ctx->vo, "%s not supported by primary plane: Falling back to %s.\n",
+ MP_VERBOSE(ctx->vo, "%s not supported by OSD plane: Falling back to %s.\n",
gbm_format_to_string(argb_format), gbm_format_to_string(xrgb_format));
result = true;
}
@@ -667,7 +667,6 @@ static bool drm_egl_init(struct ra_ctx *ctx)
}
p->drm_params.fd = p->kms->fd;
- p->drm_params.connector_id = p->kms->connector->connector_id;
p->drm_params.crtc_id = p->kms->crtc_id;
p->drm_params.connector_id = p->kms->connector->connector_id;
if (p->kms->atomic_context)
@@ -526,18 +526,18 @@ static void drm_egl_uninit(struct ra_ctx *ctx)
}
}
-// If primary plane supports ARGB we want to use that, but if it doesn't we fall
+// If the OSD plane supports ARGB we want to use that, but if it doesn't we fall
// back on XRGB. If the driver does not support atomic there is no particular
// reason to be using ARGB (drmprime hwdec will not work without atomic,